from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from mainnet.api.contract_api import ContractApi
from mainnet.api.contract_escrow_api import ContractEscrowApi
from mainnet.api.faucet_api import FaucetApi
from mainnet.api.mine_api import MineApi
from mainnet.api.util_api import UtilApi
from mainnet.api.wallet_api import WalletApi
from mainnet.api.wallet_slp_api import WalletSlpApi
from mainnet.api.wallet_util_api import WalletUtilApi
from mainnet.api.webhook_api import WebhookApi



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.slp_mint_response import SlpMintResponse  # noqa: E501
from mainnet.rest import ApiException

class TestSlpMintResponse(unittest.TestCase):
    """SlpMintResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SlpMintResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.slp_mint_response.SlpMintResponse()  # noqa: E501
        if include_optional :
            return SlpMintResponse(
                tx_id = '132731d90ac4c88a79d55eae2ad92709b415de886329e958cf35fdd81ba34c15', 
                balance = mainnet.models.slp_balance_response.SlpBalanceResponse(
                    value = '10000', 
                    ticker = 'MNC', 
                    name = 'Mainnet coin', 
                    token_id = '132731d90ac4c88a79d55eae2ad92709b415de886329e958cf35fdd81ba34c15', 
                    type = 1, )
            )
        else :
            return SlpMintResponse(
        )

    def testSlpMintResponse(self):
        """Test SlpMintResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class ElectrumRawTransaction(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'blockhash': 'str',
        'blocktime': 'float',
        'confirmations': 'float',
        'hash': 'str',
        'hex': 'str',
        'locktime': 'float',
        'size': 'float',
        'time': 'float',
        'txid': 'str',
        'version': 'float',
        'vin': 'list[ElectrumRawTransactionVin]',
        'vout': 'list[ElectrumRawTransactionVout]'
    }

    attribute_map = {
        'blockhash': 'blockhash',
        'blocktime': 'blocktime',
        'confirmations': 'confirmations',
        'hash': 'hash',
        'hex': 'hex',
        'locktime': 'locktime',
        'size': 'size',
        'time': 'time',
        'txid': 'txid',
        'version': 'version',
        'vin': 'vin',
        'vout': 'vout'
    }

    def __init__(self, blockhash=None, blocktime=None, confirmations=None, hash=None, hex=None, locktime=None, size=None, time=None, txid=None, version=None, vin=None, vout=None, local_vars_configuration=None):  # noqa: E501
        """ElectrumRawTransaction - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._blockhash = None
        self._blocktime = None
        self._confirmations = None
        self._hash = None
        self._hex = None
        self._locktime = None
        self._size = None
        self._time = None
        self._txid = None
        self._version = None
        self._vin = None
        self._vout = None
        self.discriminator = None

        if blockhash is not None:
            self.blockhash = blockhash
        if blocktime is not None:
            self.blocktime = blocktime
        if confirmations is not None:
            self.confirmations = confirmations
        if hash is not None:
            self.hash = hash
        if hex is not None:
            self.hex = hex
        if locktime is not None:
            self.locktime = locktime
        if size is not None:
            self.size = size
        if time is not None:
            self.time = time
        if txid is not None:
            self.txid = txid
        if version is not None:
            self.version = version
        if vin is not None:
            self.vin = vin
        if vout is not None:
            self.vout = vout

    @property
    def blockhash(self):
        """Gets the blockhash of this ElectrumRawTransaction.  # noqa: E501


        :return: The blockhash of this ElectrumRawTransaction.  # noqa: E501
        :rtype: str
        """
        return self._blockhash

    @blockhash.setter
    def blockhash(self, blockhash):
        """Sets the blockhash of this ElectrumRawTransaction.


        :param blockhash: The blockhash of this ElectrumRawTransaction.  # noqa: E501
        :type blockhash: str
        """

        self._blockhash = blockhash

    @property
    def blocktime(self):
        """Gets the blocktime of this ElectrumRawTransaction.  # noqa: E501


        :return: The blocktime of this ElectrumRawTransaction.  # noqa: E501
        :rtype: float
        """
        return self._blocktime

    @blocktime.setter
    def blocktime(self, blocktime):
        """Sets the blocktime of this ElectrumRawTransaction.


        :param blocktime: The blocktime of this ElectrumRawTransaction.  # noqa: E501
        :type blocktime: float
        """

        self._blocktime = blocktime

    @property
    def confirmations(self):
        """Gets the confirmations of this ElectrumRawTransaction.  # noqa: E501


        :return: The confirmations of this ElectrumRawTransaction.  # noqa: E501
        :rtype: float
        """
        return self._confirmations

    @confirmations.setter
    def confirmations(self, confirmations):
        """Sets the confirmations of this ElectrumRawTransaction.


        :param confirmations: The confirmations of this ElectrumRawTransaction.  # noqa: E501
        :type confirmations: float
        """

        self._confirmations = confirmations

    @property
    def hash(self):
        """Gets the hash of this ElectrumRawTransaction.  # noqa: E501


        :return: The hash of this ElectrumRawTransaction.  # noqa: E501
        :rtype: str
        """
        return self._hash

    @hash.setter
    def hash(self, hash):
        """Sets the hash of this ElectrumRawTransaction.


        :param hash: The hash of this ElectrumRawTransaction.  # noqa: E501
        :type hash: str
        """

        self._hash = hash

    @property
    def hex(self):
        """Gets the hex of this ElectrumRawTransaction.  # noqa: E501


        :return: The hex of this ElectrumRawTransaction.  # noqa: E501
        :rtype: str
        """
        return self._hex

    @hex.setter
    def hex(self, hex):
        """Sets the hex of this ElectrumRawTransaction.


        :param hex: The hex of this ElectrumRawTransaction.  # noqa: E501
        :type hex: str
        """

        self._hex = hex

    @property
    def locktime(self):
        """Gets the locktime of this ElectrumRawTransaction.  # noqa: E501


        :return: The locktime of this ElectrumRawTransaction.  # noqa: E501
        :rtype: float
        """
        return self._locktime

    @locktime.setter
    def locktime(self, locktime):
        """Sets the locktime of this ElectrumRawTransaction.


        :param locktime: The locktime of this ElectrumRawTransaction.  # noqa: E501
        :type locktime: float
        """

        self._locktime = locktime

    @property
    def size(self):
        """Gets the size of this ElectrumRawTransaction.  # noqa: E501


        :return: The size of this ElectrumRawTransaction.  # noqa: E501
        :rtype: float
        """
        return self._size

    @size.setter
    def size(self, size):
        """Sets the size of this ElectrumRawTransaction.


        :param size: The size of this ElectrumRawTransaction.  # noqa: E501
        :type size: float
        """

        self._size = size

    @property
    def time(self):
        """Gets the time of this ElectrumRawTransaction.  # noqa: E501


        :return: The time of this ElectrumRawTransaction.  # noqa: E501
        :rtype: float
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this ElectrumRawTransaction.


        :param time: The time of this ElectrumRawTransaction.  # noqa: E501
        :type time: float
        """

        self._time = time

    @property
    def txid(self):
        """Gets the txid of this ElectrumRawTransaction.  # noqa: E501


        :return: The txid of this ElectrumRawTransaction.  # noqa: E501
        :rtype: str
        """
        return self._txid

    @txid.setter
    def txid(self, txid):
        """Sets the txid of this ElectrumRawTransaction.


        :param txid: The txid of this ElectrumRawTransaction.  # noqa: E501
        :type txid: str
        """

        self._txid = txid

    @property
    def version(self):
        """Gets the version of this ElectrumRawTransaction.  # noqa: E501


        :return: The version of this ElectrumRawTransaction.  # noqa: E501
        :rtype: float
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ElectrumRawTransaction.


        :param version: The version of this ElectrumRawTransaction.  # noqa: E501
        :type version: float
        """

        self._version = version

    @property
    def vin(self):
        """Gets the vin of this ElectrumRawTransaction.  # noqa: E501


        :return: The vin of this ElectrumRawTransaction.  # noqa: E501
        :rtype: list[ElectrumRawTransactionVin]
        """
        return self._vin

    @vin.setter
    def vin(self, vin):
        """Sets the vin of this ElectrumRawTransaction.


        :param vin: The vin of this ElectrumRawTransaction.  # noqa: E501
        :type vin: list[ElectrumRawTransactionVin]
        """

        self._vin = vin

    @property
    def vout(self):
        """Gets the vout of this ElectrumRawTransaction.  # noqa: E501


        :return: The vout of this ElectrumRawTransaction.  # noqa: E501
        :rtype: list[ElectrumRawTransactionVout]
        """
        return self._vout

    @vout.setter
    def vout(self, vout):
        """Sets the vout of this ElectrumRawTransaction.


        :param vout: The vout of this ElectrumRawTransaction.  # noqa: E501
        :type vout: list[ElectrumRawTransactionVout]
        """

        self._vout = vout

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ElectrumRawTransaction):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ElectrumRawTransaction):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class EscrowFnRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'escrow_contract_id': 'str',
        'wallet_id': 'str',
        'function': 'str',
        'to': 'str',
        'action': 'str',
        'utxo_ids': 'list[str]'
    }

    attribute_map = {
        'escrow_contract_id': 'escrowContractId',
        'wallet_id': 'walletId',
        'function': 'function',
        'to': 'to',
        'action': 'action',
        'utxo_ids': 'utxoIds'
    }

    def __init__(self, escrow_contract_id=None, wallet_id=None, function=None, to=None, action=None, utxo_ids=None, local_vars_configuration=None):  # noqa: E501
        """EscrowFnRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._escrow_contract_id = None
        self._wallet_id = None
        self._function = None
        self._to = None
        self._action = None
        self._utxo_ids = None
        self.discriminator = None

        self.escrow_contract_id = escrow_contract_id
        self.wallet_id = wallet_id
        self.function = function
        if to is not None:
            self.to = to
        if action is not None:
            self.action = action
        if utxo_ids is not None:
            self.utxo_ids = utxo_ids

    @property
    def escrow_contract_id(self):
        """Gets the escrow_contract_id of this EscrowFnRequest.  # noqa: E501

        serialized contract   # noqa: E501

        :return: The escrow_contract_id of this EscrowFnRequest.  # noqa: E501
        :rtype: str
        """
        return self._escrow_contract_id

    @escrow_contract_id.setter
    def escrow_contract_id(self, escrow_contract_id):
        """Sets the escrow_contract_id of this EscrowFnRequest.

        serialized contract   # noqa: E501

        :param escrow_contract_id: The escrow_contract_id of this EscrowFnRequest.  # noqa: E501
        :type escrow_contract_id: str
        """
        if self.local_vars_configuration.client_side_validation and escrow_contract_id is None:  # noqa: E501
            raise ValueError("Invalid value for `escrow_contract_id`, must not be `None`")  # noqa: E501

        self._escrow_contract_id = escrow_contract_id

    @property
    def wallet_id(self):
        """Gets the wallet_id of this EscrowFnRequest.  # noqa: E501

        The walletId of the transaction signer.   # noqa: E501

        :return: The wallet_id of this EscrowFnRequest.  # noqa: E501
        :rtype: str
        """
        return self._wallet_id

    @wallet_id.setter
    def wallet_id(self, wallet_id):
        """Sets the wallet_id of this EscrowFnRequest.

        The walletId of the transaction signer.   # noqa: E501

        :param wallet_id: The wallet_id of this EscrowFnRequest.  # noqa: E501
        :type wallet_id: str
        """
        if self.local_vars_configuration.client_side_validation and wallet_id is None:  # noqa: E501
            raise ValueError("Invalid value for `wallet_id`, must not be `None`")  # noqa: E501

        self._wallet_id = wallet_id

    @property
    def function(self):
        """Gets the function of this EscrowFnRequest.  # noqa: E501

        Function to call on the escrow contract.  # noqa: E501

        :return: The function of this EscrowFnRequest.  # noqa: E501
        :rtype: str
        """
        return self._function

    @function.setter
    def function(self, function):
        """Sets the function of this EscrowFnRequest.

        Function to call on the escrow contract.  # noqa: E501

        :param function: The function of this EscrowFnRequest.  # noqa: E501
        :type function: str
        """
        if self.local_vars_configuration.client_side_validation and function is None:  # noqa: E501
            raise ValueError("Invalid value for `function`, must not be `None`")  # noqa: E501
        allowed_values = ["spend", "refund"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and function not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `function` ({0}), must be one of {1}"  # noqa: E501
                .format(function, allowed_values)
            )

        self._function = function

    @property
    def to(self):
        """Gets the to of this EscrowFnRequest.  # noqa: E501

        Output address for the transaction  # noqa: E501

        :return: The to of this EscrowFnRequest.  # noqa: E501
        :rtype: str
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this EscrowFnRequest.

        Output address for the transaction  # noqa: E501

        :param to: The to of this EscrowFnRequest.  # noqa: E501
        :type to: str
        """

        self._to = to

    @property
    def action(self):
        """Gets the action of this EscrowFnRequest.  # noqa: E501

        In addition to `send`ing the built transaction, the built transaction hex may be returned (without broadcasting) with `build` action, or the [`meep 🔗`](https://github.com/gcash/meep) debugger command  # noqa: E501

        :return: The action of this EscrowFnRequest.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this EscrowFnRequest.

        In addition to `send`ing the built transaction, the built transaction hex may be returned (without broadcasting) with `build` action, or the [`meep 🔗`](https://github.com/gcash/meep) debugger command  # noqa: E501

        :param action: The action of this EscrowFnRequest.  # noqa: E501
        :type action: str
        """
        allowed_values = ["build", "send", "meep"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and action not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `action` ({0}), must be one of {1}"  # noqa: E501
                .format(action, allowed_values)
            )

        self._action = action

    @property
    def utxo_ids(self):
        """Gets the utxo_ids of this EscrowFnRequest.  # noqa: E501


        :return: The utxo_ids of this EscrowFnRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._utxo_ids

    @utxo_ids.setter
    def utxo_ids(self, utxo_ids):
        """Sets the utxo_ids of this EscrowFnRequest.


        :param utxo_ids: The utxo_ids of this EscrowFnRequest.  # noqa: E501
        :type utxo_ids: list[str]
        """

        self._utxo_ids = utxo_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EscrowFnRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EscrowFnRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class BalanceResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bch': 'float',
        'sat': 'int',
        'usd': 'float'
    }

    attribute_map = {
        'bch': 'bch',
        'sat': 'sat',
        'usd': 'usd'
    }

    def __init__(self, bch=None, sat=None, usd=None, local_vars_configuration=None):  # noqa: E501
        """BalanceResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._bch = None
        self._sat = None
        self._usd = None
        self.discriminator = None

        if bch is not None:
            self.bch = bch
        if sat is not None:
            self.sat = sat
        if usd is not None:
            self.usd = usd

    @property
    def bch(self):
        """Gets the bch of this BalanceResponse.  # noqa: E501

        Amount in whole Bitcoin Cash  # noqa: E501

        :return: The bch of this BalanceResponse.  # noqa: E501
        :rtype: float
        """
        return self._bch

    @bch.setter
    def bch(self, bch):
        """Sets the bch of this BalanceResponse.

        Amount in whole Bitcoin Cash  # noqa: E501

        :param bch: The bch of this BalanceResponse.  # noqa: E501
        :type bch: float
        """

        self._bch = bch

    @property
    def sat(self):
        """Gets the sat of this BalanceResponse.  # noqa: E501

        Amount in satoshis  # noqa: E501

        :return: The sat of this BalanceResponse.  # noqa: E501
        :rtype: int
        """
        return self._sat

    @sat.setter
    def sat(self, sat):
        """Sets the sat of this BalanceResponse.

        Amount in satoshis  # noqa: E501

        :param sat: The sat of this BalanceResponse.  # noqa: E501
        :type sat: int
        """

        self._sat = sat

    @property
    def usd(self):
        """Gets the usd of this BalanceResponse.  # noqa: E501

        Amount in United States Dollars  # noqa: E501

        :return: The usd of this BalanceResponse.  # noqa: E501
        :rtype: float
        """
        return self._usd

    @usd.setter
    def usd(self, usd):
        """Sets the usd of this BalanceResponse.

        Amount in United States Dollars  # noqa: E501

        :param usd: The usd of this BalanceResponse.  # noqa: E501
        :type usd: float
        """

        self._usd = usd

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BalanceResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BalanceResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.contract_fn_response import ContractFnResponse  # noqa: E501
from mainnet.rest import ApiException

class TestContractFnResponse(unittest.TestCase):
    """ContractFnResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ContractFnResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.contract_fn_response.ContractFnResponse()  # noqa: E501
        if include_optional :
            return ContractFnResponse(
                contract_id = '0', 
                tx_id = '1e6442a0d3548bb4f917721184ac1cb163ddf324e2c09f55c46ff0ba521cb89f', 
                hex = '0200000001f6d804c0a2f33936dd8b535d1... bdf0e43b30135be5251', 
                debug = 'meep debug --tx=0200000001b3f2d1ce4951d104e8244310943c49cd8ea59b437fa5b794197fcffc32cfc28900000000b941b0e8a077ea6d70c757487a14c175c9ed21a5f4f54d0477578ac3bc89da86cbb5567f62eb9b46c49c328f02165a54a577cc4228fd2dd5a5497fc25a638f0205b1412103410ef048b3da351793f6ed14cc2fde460becc5b658d9138443b9a3000707a6a7514c5202d70014a72d8e8dc9ca261e8ffafba96514ee92b0c2bf271456b6b22042b90dd67bf2fbfb9aff7d37fbee11245379009c63557a5579ad547aa97b8777777767537a519d547a5479ad537aa9887cb16d5168feffffff0268420000000000001976a91456b6b22042b90dd67bf2fbfb9aff7d37fbee112488ac720e00000000000017a914d411d850ed6395e6e72a5e0497a54ab99a75b84387d7000000 --idx=0 --amt=21000 --pkscript=a914d411d850ed6395e6e72a5e0497a54ab99a75b84387
'
            )
        else :
            return ContractFnResponse(
        )

    def testContractFnResponse(self):
        """Test ContractFnResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.send_max_response import SendMaxResponse  # noqa: E501
from mainnet.rest import ApiException

class TestSendMaxResponse(unittest.TestCase):
    """SendMaxResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SendMaxResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.send_max_response.SendMaxResponse()  # noqa: E501
        if include_optional :
            return SendMaxResponse(
                tx_id = '1e6442a0d3548bb4f917721184ac1cb163ddf324e2c09f55c46ff0ba521cb89f', 
                balance = mainnet.models.zero_balance_response.ZeroBalanceResponse(
                    bch = 0, 
                    sat = 0, 
                    usd = 0, )
            )
        else :
            return SendMaxResponse(
        )

    def testSendMaxResponse(self):
        """Test SendMaxResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.send_max_request import SendMaxRequest  # noqa: E501
from mainnet.rest import ApiException

class TestSendMaxRequest(unittest.TestCase):
    """SendMaxRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SendMaxRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.send_max_request.SendMaxRequest()  # noqa: E501
        if include_optional :
            return SendMaxRequest(
                wallet_id = 'wif:testnet:cNfsPtqN2bMRS7vH5qd8tR8GMvgXyL5BjnGAKgZ8DYEiCrCCQcP6', 
                cashaddr = 'bchtest:qpalhxhl05mlhms3ys43u76rn0ttdv3qg2usm4nm7t', 
                options = mainnet.models.send_request_options.SendRequestOptions(
                    utxo_ids = [
                        '1e6442a0d3548bb4f917721184ac1cb163ddf324e2c09f55c46ff0ba521cb89f:0:5000'
                        ], 
                    change_address = 'bchtest:qzd0tv75gx6y0zspzwqpgkwkq0n72g8fsq2zch26s2', 
                    slp_aware = True, 
                    query_balance = False, 
                    await_transaction_propagation = False, )
            )
        else :
            return SendMaxRequest(
                wallet_id = 'wif:testnet:cNfsPtqN2bMRS7vH5qd8tR8GMvgXyL5BjnGAKgZ8DYEiCrCCQcP6',
                cashaddr = 'bchtest:qpalhxhl05mlhms3ys43u76rn0ttdv3qg2usm4nm7t',
        )

    def testSendMaxRequest(self):
        """Test SendMaxRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class VerifySignedMessageResponseDetails(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'signature_type': 'str',
        'message_hash': 'str',
        'signature_valid': 'bool',
        'public_key_hash_match': 'bool'
    }

    attribute_map = {
        'signature_type': 'signatureType',
        'message_hash': 'messageHash',
        'signature_valid': 'signatureValid',
        'public_key_hash_match': 'publicKeyHashMatch'
    }

    def __init__(self, signature_type=None, message_hash=None, signature_valid=None, public_key_hash_match=None, local_vars_configuration=None):  # noqa: E501
        """VerifySignedMessageResponseDetails - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._signature_type = None
        self._message_hash = None
        self._signature_valid = None
        self._public_key_hash_match = None
        self.discriminator = None

        if signature_type is not None:
            self.signature_type = signature_type
        if message_hash is not None:
            self.message_hash = message_hash
        if signature_valid is not None:
            self.signature_valid = signature_valid
        if public_key_hash_match is not None:
            self.public_key_hash_match = public_key_hash_match

    @property
    def signature_type(self):
        """Gets the signature_type of this VerifySignedMessageResponseDetails.  # noqa: E501

        The type of signature passed  # noqa: E501

        :return: The signature_type of this VerifySignedMessageResponseDetails.  # noqa: E501
        :rtype: str
        """
        return self._signature_type

    @signature_type.setter
    def signature_type(self, signature_type):
        """Sets the signature_type of this VerifySignedMessageResponseDetails.

        The type of signature passed  # noqa: E501

        :param signature_type: The signature_type of this VerifySignedMessageResponseDetails.  # noqa: E501
        :type signature_type: str
        """

        self._signature_type = signature_type

    @property
    def message_hash(self):
        """Gets the message_hash of this VerifySignedMessageResponseDetails.  # noqa: E501

        The double sha256 hash of the string encoded as Bitcoin Message binary.  # noqa: E501

        :return: The message_hash of this VerifySignedMessageResponseDetails.  # noqa: E501
        :rtype: str
        """
        return self._message_hash

    @message_hash.setter
    def message_hash(self, message_hash):
        """Sets the message_hash of this VerifySignedMessageResponseDetails.

        The double sha256 hash of the string encoded as Bitcoin Message binary.  # noqa: E501

        :param message_hash: The message_hash of this VerifySignedMessageResponseDetails.  # noqa: E501
        :type message_hash: str
        """

        self._message_hash = message_hash

    @property
    def signature_valid(self):
        """Gets the signature_valid of this VerifySignedMessageResponseDetails.  # noqa: E501

        A boolean indicating whether the signature is valid for the message  # noqa: E501

        :return: The signature_valid of this VerifySignedMessageResponseDetails.  # noqa: E501
        :rtype: bool
        """
        return self._signature_valid

    @signature_valid.setter
    def signature_valid(self, signature_valid):
        """Sets the signature_valid of this VerifySignedMessageResponseDetails.

        A boolean indicating whether the signature is valid for the message  # noqa: E501

        :param signature_valid: The signature_valid of this VerifySignedMessageResponseDetails.  # noqa: E501
        :type signature_valid: bool
        """

        self._signature_valid = signature_valid

    @property
    def public_key_hash_match(self):
        """Gets the public_key_hash_match of this VerifySignedMessageResponseDetails.  # noqa: E501

        A boolean indicating whether the publicKeyHash of a recoverable signature matches the provided cashaddr, false otherwise  # noqa: E501

        :return: The public_key_hash_match of this VerifySignedMessageResponseDetails.  # noqa: E501
        :rtype: bool
        """
        return self._public_key_hash_match

    @public_key_hash_match.setter
    def public_key_hash_match(self, public_key_hash_match):
        """Sets the public_key_hash_match of this VerifySignedMessageResponseDetails.

        A boolean indicating whether the publicKeyHash of a recoverable signature matches the provided cashaddr, false otherwise  # noqa: E501

        :param public_key_hash_match: The public_key_hash_match of this VerifySignedMessageResponseDetails.  # noqa: E501
        :type public_key_hash_match: bool
        """

        self._public_key_hash_match = public_key_hash_match

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, VerifySignedMessageResponseDetails):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, VerifySignedMessageResponseDetails):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class EscrowRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'buyer_addr': 'object',
        'arbiter_addr': 'object',
        'seller_addr': 'object',
        'amount': 'float'
    }

    attribute_map = {
        'buyer_addr': 'buyerAddr',
        'arbiter_addr': 'arbiterAddr',
        'seller_addr': 'sellerAddr',
        'amount': 'amount'
    }

    def __init__(self, buyer_addr=None, arbiter_addr=None, seller_addr=None, amount=None, local_vars_configuration=None):  # noqa: E501
        """EscrowRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._buyer_addr = None
        self._arbiter_addr = None
        self._seller_addr = None
        self._amount = None
        self.discriminator = None

        self.buyer_addr = buyer_addr
        self.arbiter_addr = arbiter_addr
        self.seller_addr = seller_addr
        self.amount = amount

    @property
    def buyer_addr(self):
        """Gets the buyer_addr of this EscrowRequest.  # noqa: E501

        The cashaddress of the buyer  # noqa: E501

        :return: The buyer_addr of this EscrowRequest.  # noqa: E501
        :rtype: object
        """
        return self._buyer_addr

    @buyer_addr.setter
    def buyer_addr(self, buyer_addr):
        """Sets the buyer_addr of this EscrowRequest.

        The cashaddress of the buyer  # noqa: E501

        :param buyer_addr: The buyer_addr of this EscrowRequest.  # noqa: E501
        :type buyer_addr: object
        """

        self._buyer_addr = buyer_addr

    @property
    def arbiter_addr(self):
        """Gets the arbiter_addr of this EscrowRequest.  # noqa: E501

        The cashaddress of the arbiter  # noqa: E501

        :return: The arbiter_addr of this EscrowRequest.  # noqa: E501
        :rtype: object
        """
        return self._arbiter_addr

    @arbiter_addr.setter
    def arbiter_addr(self, arbiter_addr):
        """Sets the arbiter_addr of this EscrowRequest.

        The cashaddress of the arbiter  # noqa: E501

        :param arbiter_addr: The arbiter_addr of this EscrowRequest.  # noqa: E501
        :type arbiter_addr: object
        """

        self._arbiter_addr = arbiter_addr

    @property
    def seller_addr(self):
        """Gets the seller_addr of this EscrowRequest.  # noqa: E501

        The cashaddress of the seller  # noqa: E501

        :return: The seller_addr of this EscrowRequest.  # noqa: E501
        :rtype: object
        """
        return self._seller_addr

    @seller_addr.setter
    def seller_addr(self, seller_addr):
        """Sets the seller_addr of this EscrowRequest.

        The cashaddress of the seller  # noqa: E501

        :param seller_addr: The seller_addr of this EscrowRequest.  # noqa: E501
        :type seller_addr: object
        """

        self._seller_addr = seller_addr

    @property
    def amount(self):
        """Gets the amount of this EscrowRequest.  # noqa: E501

        Numeric amount to be transferred by the contract in satoshi, amount must be less than 21 BCH.  # noqa: E501

        :return: The amount of this EscrowRequest.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this EscrowRequest.

        Numeric amount to be transferred by the contract in satoshi, amount must be less than 21 BCH.  # noqa: E501

        :param amount: The amount of this EscrowRequest.  # noqa: E501
        :type amount: float
        """
        if self.local_vars_configuration.client_side_validation and amount is None:  # noqa: E501
            raise ValueError("Invalid value for `amount`, must not be `None`")  # noqa: E501

        self._amount = amount

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EscrowRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EscrowRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.escrow_info_response import EscrowInfoResponse  # noqa: E501
from mainnet.rest import ApiException

class TestEscrowInfoResponse(unittest.TestCase):
    """EscrowInfoResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EscrowInfoResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.escrow_info_response.EscrowInfoResponse()  # noqa: E501
        if include_optional :
            return EscrowInfoResponse(
                escrow_contract_id = 'escrowContract:testnet:WW1Ob2RHVnpkRHB4ZWpBd2NHczViR1p6TUdzNVpqVjJaak5xT0dnMk5uRm1iWEZoWjJzNGJtTTFObVZzY1RSa2RqST06WW1Ob2RHVnpkRHB4Y201c2RYVm5aVFUyWVdoNGMzazJjSEJzY1RRemNuWmhOMnMyY3psa2EyNTFOSEExTWpjNFlXZz06WW1Ob2RHVnpkRHB4ZW5Od1kzbDNlRzF0TkdaeGFHWTVhMnB5YTI1eVl6Tm5jbk4yTW5aMWEyVnhlV3B4YkdFd2JuUT06TVRBd01EQT0=:TVRVNExESTBNQ3d5TVRZc01Ua3hMRGMyTERNeExEazRMREUyTml3eE5EQXNOellzTVRBd0xERXlNeXd5TXpVc05qUXNOemdzTVRrekxESXhNaXc0T0N3eU5ETXNNVGszOk1qTXhMREkxTkN3eE1UTXNNalVzTVRZMkxERTROeXd4TVRVc05qUXNNVFUwTERnc01USTJMREV3TERFNU5pd3hNRGdzTWpNNUxERTNNeXd4Tmpnc01qRXNNVGd5TERFMU9RPT06TVRZd0xESTRMREUzTERFNU9Dd3lNaklzTWpNMExERTBOQ3c1TXl3ek55d3hPREFzTVRNMUxERXdOU3d4TkRNc01UY3NOalFzTWpJMExERTVOeXcxTVN3eE5UQXNNakF3Ok1UQXdNREE9Ok1UQTNOVEU0TkRjeU53PT0=:cHJhZ21hIGNhc2hzY3JpcHQgXjAuNi4xOwogICAgICAgICAgICBjb250cmFjdCBlc2Nyb3coYnl0ZXMyMCBzZWxsZXJQa2gsIGJ5dGVzMjAgYnV5ZXJQa2gsIGJ5dGVzMjAgYXJiaXRlclBraCwgaW50IGNvbnRyYWN0QW1vdW50LCBpbnQgY29udHJhY3ROb25jZSkgewoKICAgICAgICAgICAgICAgIGZ1bmN0aW9uIHNwZW5kKHB1YmtleSBzaWduaW5nUGssIHNpZyBzLCBpbnQgYW1vdW50LCBpbnQgbm9uY2UpIHsKICAgICAgICAgICAgICAgICAgICByZXF1aXJlKGhhc2gxNjAoc2lnbmluZ1BrKSA9PSBhcmJpdGVyUGtoIHx8IGhhc2gxNjAoc2lnbmluZ1BrKSA9PSBidXllclBraCk7CiAgICAgICAgICAgICAgICAgICAgcmVxdWlyZShjaGVja1NpZyhzLCBzaWduaW5nUGspKTsKICAgICAgICAgICAgICAgICAgICByZXF1aXJlKGFtb3VudCA+PSBjb250cmFjdEFtb3VudCk7CiAgICAgICAgICAgICAgICAgICAgcmVxdWlyZShub25jZSA9PSBjb250cmFjdE5vbmNlKTsKICAgICAgICAgICAgICAgICAgICBieXRlczM0IG91dHB1dCA9IG5ldyBPdXRwdXRQMlBLSChieXRlczgoYW1vdW50KSwgc2VsbGVyUGtoKTsKICAgICAgICAgICAgICAgICAgICByZXF1aXJlKGhhc2gyNTYob3V0cHV0KSA9PSB0eC5oYXNoT3V0cHV0cyk7CiAgICAgICAgICAgICAgICB9CgogICAgICAgICAgICAgICAgZnVuY3Rpb24gcmVmdW5kKHB1YmtleSBzaWduaW5nUGssIHNpZyBzLCBpbnQgYW1vdW50LCBpbnQgbm9uY2UpIHsKICAgICAgICAgICAgICAgICAgICByZXF1aXJlKGhhc2gxNjAoc2lnbmluZ1BrKSA9PSBhcmJpdGVyUGtofHxoYXNoMTYwKHNpZ25pbmdQaykgPT0gc2VsbGVyUGtoKTsKICAgICAgICAgICAgICAgICAgICByZXF1aXJlKGNoZWNrU2lnKHMsIHNpZ25pbmdQaykpOwogICAgICAgICAgICAgICAgICAgIHJlcXVpcmUoYW1vdW50ID49IGNvbnRyYWN0QW1vdW50KTsKICAgICAgICAgICAgICAgICAgICByZXF1aXJlKG5vbmNlID09IGNvbnRyYWN0Tm9uY2UpOwogICAgICAgICAgICAgICAgICAgIGJ5dGVzMzQgb3V0cHV0ID0gbmV3IE91dHB1dFAyUEtIKGJ5dGVzOChhbW91bnQpLCBidXllclBraCk7CiAgICAgICAgICAgICAgICAgICAgcmVxdWlyZShoYXNoMjU2KG91dHB1dCkgPT0gdHguaGFzaE91dHB1dHMpOwogICAgICAgICAgICAgICAgfQogICAgICAgICAgICB9CiAgICAgICAg:1075184727', 
                script = 'pragma cashscript ^0.6.1;
contract escrow(bytes20 sellerPkh, bytes20 buyerPkh, bytes20 arbiterPkh, int contractAmount, int contractNonce) {

    function spend(pubkey signingPk, sig s, int amount, int nonce) {
        require(hash160(signingPk) == arbiterPkh || hash160(signingPk) == buyerPkh);
        require(checkSig(s, signingPk));
        require(amount >= contractAmount);
        require(nonce == contractNonce);
        bytes34 output = new OutputP2PKH(bytes8(amount), sellerPkh);
        require(hash256(output) == tx.hashOutputs);
    }

    function refund(pubkey signingPk, sig s, int amount, int nonce) {
        require(hash160(signingPk) == arbiterPkh||hash160(signingPk) == sellerPkh);
        require(checkSig(s, signingPk));
        require(amount >= contractAmount);
        require(nonce == contractNonce);
        bytes34 output = new OutputP2PKH(bytes8(amount), buyerPkh);
        require(hash256(output) == tx.hashOutputs);
    }
}            
', 
                parameters = ["9ef0d8bf4c1f62a68c4c647beb404ec1d458f3c5","e7fe7119a6bb73409a087e0ac46cefada815b69f","a01c11c6deea905d25b487698f1140e0c53396c8",10000,1996128042], 
                cashaddr = 'bchtest:prxla49zwqm8m2nzgn82qza3ssrqnpt8vgv60hlwm2', 
                buyer_addr = bchtest:qrnluuge56ahxsy6pplq43rva7k6s9dknu4p5278ah, 
                arbiter_addr = bchtest:qzspcywxmm4fqhf9kjrknrc3grsv2vukeqyjqla0nt, 
                seller_addr = bchtest:qz00pk9lfs0k9f5vf3j8h66qfmqagk8nc56elq4dv2, 
                amount = 10000, 
                nonce = 1996128042
            )
        else :
            return EscrowInfoResponse(
        )

    def testEscrowInfoResponse(self):
        """Test EscrowInfoResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class ElectrumRawTransactionVin(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'script_sig': 'ElectrumRawTransactionScriptSig',
        'sequence': 'float',
        'txid': 'str',
        'vout': 'float',
        'value': 'float',
        'address': 'str'
    }

    attribute_map = {
        'script_sig': 'scriptSig',
        'sequence': 'sequence',
        'txid': 'txid',
        'vout': 'vout',
        'value': 'value',
        'address': 'address'
    }

    def __init__(self, script_sig=None, sequence=None, txid=None, vout=None, value=None, address=None, local_vars_configuration=None):  # noqa: E501
        """ElectrumRawTransactionVin - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._script_sig = None
        self._sequence = None
        self._txid = None
        self._vout = None
        self._value = None
        self._address = None
        self.discriminator = None

        if script_sig is not None:
            self.script_sig = script_sig
        if sequence is not None:
            self.sequence = sequence
        if txid is not None:
            self.txid = txid
        if vout is not None:
            self.vout = vout
        if value is not None:
            self.value = value
        if address is not None:
            self.address = address

    @property
    def script_sig(self):
        """Gets the script_sig of this ElectrumRawTransactionVin.  # noqa: E501


        :return: The script_sig of this ElectrumRawTransactionVin.  # noqa: E501
        :rtype: ElectrumRawTransactionScriptSig
        """
        return self._script_sig

    @script_sig.setter
    def script_sig(self, script_sig):
        """Sets the script_sig of this ElectrumRawTransactionVin.


        :param script_sig: The script_sig of this ElectrumRawTransactionVin.  # noqa: E501
        :type script_sig: ElectrumRawTransactionScriptSig
        """

        self._script_sig = script_sig

    @property
    def sequence(self):
        """Gets the sequence of this ElectrumRawTransactionVin.  # noqa: E501


        :return: The sequence of this ElectrumRawTransactionVin.  # noqa: E501
        :rtype: float
        """
        return self._sequence

    @sequence.setter
    def sequence(self, sequence):
        """Sets the sequence of this ElectrumRawTransactionVin.


        :param sequence: The sequence of this ElectrumRawTransactionVin.  # noqa: E501
        :type sequence: float
        """

        self._sequence = sequence

    @property
    def txid(self):
        """Gets the txid of this ElectrumRawTransactionVin.  # noqa: E501


        :return: The txid of this ElectrumRawTransactionVin.  # noqa: E501
        :rtype: str
        """
        return self._txid

    @txid.setter
    def txid(self, txid):
        """Sets the txid of this ElectrumRawTransactionVin.


        :param txid: The txid of this ElectrumRawTransactionVin.  # noqa: E501
        :type txid: str
        """

        self._txid = txid

    @property
    def vout(self):
        """Gets the vout of this ElectrumRawTransactionVin.  # noqa: E501


        :return: The vout of this ElectrumRawTransactionVin.  # noqa: E501
        :rtype: float
        """
        return self._vout

    @vout.setter
    def vout(self, vout):
        """Sets the vout of this ElectrumRawTransactionVin.


        :param vout: The vout of this ElectrumRawTransactionVin.  # noqa: E501
        :type vout: float
        """

        self._vout = vout

    @property
    def value(self):
        """Gets the value of this ElectrumRawTransactionVin.  # noqa: E501

        optional extention by mainnet.cash  # noqa: E501

        :return: The value of this ElectrumRawTransactionVin.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this ElectrumRawTransactionVin.

        optional extention by mainnet.cash  # noqa: E501

        :param value: The value of this ElectrumRawTransactionVin.  # noqa: E501
        :type value: float
        """

        self._value = value

    @property
    def address(self):
        """Gets the address of this ElectrumRawTransactionVin.  # noqa: E501

        optional extention by mainnet.cash  # noqa: E501

        :return: The address of this ElectrumRawTransactionVin.  # noqa: E501
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """Sets the address of this ElectrumRawTransactionVin.

        optional extention by mainnet.cash  # noqa: E501

        :param address: The address of this ElectrumRawTransactionVin.  # noqa: E501
        :type address: str
        """

        self._address = address

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ElectrumRawTransactionVin):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ElectrumRawTransactionVin):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mainnet
from mainnet.api.wallet_slp_api import WalletSlpApi  # noqa: E501
from mainnet.rest import ApiException


class TestWalletSlpApi(unittest.TestCase):
    """WalletSlpApi unit test stubs"""

    def setUp(self):
        self.api = mainnet.api.wallet_slp_api.WalletSlpApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_nft_child_genesis(self):
        """Test case for nft_child_genesis

        Get created tokenId back and new NFT child token balance of the wallet  # noqa: E501
        """
        pass

    def test_nft_parent_genesis(self):
        """Test case for nft_parent_genesis

        Get created tokenId back and new NFT token balance of the wallet  # noqa: E501
        """
        pass

    def test_slp_all_balances(self):
        """Test case for slp_all_balances

        Get all slp balances of the wallet  # noqa: E501
        """
        pass

    def test_slp_balance(self):
        """Test case for slp_balance

        Get total slp token balance of the wallet  # noqa: E501
        """
        pass

    def test_slp_create_wallet(self):
        """Test case for slp_create_wallet

        create a new SLP wallet  # noqa: E501
        """
        pass

    def test_slp_deposit_address(self):
        """Test case for slp_deposit_address

        Get an SLP deposit address in cash address format  # noqa: E501
        """
        pass

    def test_slp_deposit_qr(self):
        """Test case for slp_deposit_qr

        Get an SLP receiving cash address as a qrcode  # noqa: E501
        """
        pass

    def test_slp_genesis(self):
        """Test case for slp_genesis

        Get created tokenId back and new slp token balance of the wallet  # noqa: E501
        """
        pass

    def test_slp_mint(self):
        """Test case for slp_mint

        Get created tokenId back and new slp token balance of the wallet  # noqa: E501
        """
        pass

    def test_slp_outpoints(self):
        """Test case for slp_outpoints

        Get list of unspent SLP outpoints.  # noqa: E501
        """
        pass

    def test_slp_send(self):
        """Test case for slp_send

        Send some SLP token amount to a given cash address  # noqa: E501
        """
        pass

    def test_slp_send_max(self):
        """Test case for slp_send_max

        Send all available SLP funds to a given address  # noqa: E501
        """
        pass

    def test_slp_token_info(self):
        """Test case for slp_token_info

        Get information about the token  # noqa: E501
        """
        pass

    def test_slp_utxos(self):
        """Test case for slp_utxos

        Get detailed information about unspent SLP outputs (utxos)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class SendMaxRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'wallet_id': 'str',
        'cashaddr': 'str',
        'options': 'SendRequestOptions'
    }

    attribute_map = {
        'wallet_id': 'walletId',
        'cashaddr': 'cashaddr',
        'options': 'options'
    }

    def __init__(self, wallet_id=None, cashaddr=None, options=None, local_vars_configuration=None):  # noqa: E501
        """SendMaxRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._wallet_id = None
        self._cashaddr = None
        self._options = None
        self.discriminator = None

        self.wallet_id = wallet_id
        self.cashaddr = cashaddr
        if options is not None:
            self.options = options

    @property
    def wallet_id(self):
        """Gets the wallet_id of this SendMaxRequest.  # noqa: E501

        The walletId of the sender   # noqa: E501

        :return: The wallet_id of this SendMaxRequest.  # noqa: E501
        :rtype: str
        """
        return self._wallet_id

    @wallet_id.setter
    def wallet_id(self, wallet_id):
        """Sets the wallet_id of this SendMaxRequest.

        The walletId of the sender   # noqa: E501

        :param wallet_id: The wallet_id of this SendMaxRequest.  # noqa: E501
        :type wallet_id: str
        """
        if self.local_vars_configuration.client_side_validation and wallet_id is None:  # noqa: E501
            raise ValueError("Invalid value for `wallet_id`, must not be `None`")  # noqa: E501

        self._wallet_id = wallet_id

    @property
    def cashaddr(self):
        """Gets the cashaddr of this SendMaxRequest.  # noqa: E501


        :return: The cashaddr of this SendMaxRequest.  # noqa: E501
        :rtype: str
        """
        return self._cashaddr

    @cashaddr.setter
    def cashaddr(self, cashaddr):
        """Sets the cashaddr of this SendMaxRequest.


        :param cashaddr: The cashaddr of this SendMaxRequest.  # noqa: E501
        :type cashaddr: str
        """
        if self.local_vars_configuration.client_side_validation and cashaddr is None:  # noqa: E501
            raise ValueError("Invalid value for `cashaddr`, must not be `None`")  # noqa: E501

        self._cashaddr = cashaddr

    @property
    def options(self):
        """Gets the options of this SendMaxRequest.  # noqa: E501


        :return: The options of this SendMaxRequest.  # noqa: E501
        :rtype: SendRequestOptions
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this SendMaxRequest.


        :param options: The options of this SendMaxRequest.  # noqa: E501
        :type options: SendRequestOptions
        """

        self._options = options

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendMaxRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SendMaxRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class SlpGenesisRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'wallet_id': 'str',
        'name': 'str',
        'ticker': 'str',
        'initial_amount': 'str',
        'decimals': 'float',
        'document_url': 'str',
        'document_hash': 'str',
        'end_baton': 'bool',
        'type': 'float',
        'token_receiver_slp_addr': 'str',
        'baton_receiver_slp_addr': 'str',
        'parent_token_id': 'str'
    }

    attribute_map = {
        'wallet_id': 'walletId',
        'name': 'name',
        'ticker': 'ticker',
        'initial_amount': 'initialAmount',
        'decimals': 'decimals',
        'document_url': 'documentUrl',
        'document_hash': 'documentHash',
        'end_baton': 'endBaton',
        'type': 'type',
        'token_receiver_slp_addr': 'tokenReceiverSlpAddr',
        'baton_receiver_slp_addr': 'batonReceiverSlpAddr',
        'parent_token_id': 'parentTokenId'
    }

    def __init__(self, wallet_id=None, name=None, ticker=None, initial_amount=None, decimals=None, document_url=None, document_hash=None, end_baton=None, type=None, token_receiver_slp_addr=None, baton_receiver_slp_addr=None, parent_token_id=None, local_vars_configuration=None):  # noqa: E501
        """SlpGenesisRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._wallet_id = None
        self._name = None
        self._ticker = None
        self._initial_amount = None
        self._decimals = None
        self._document_url = None
        self._document_hash = None
        self._end_baton = None
        self._type = None
        self._token_receiver_slp_addr = None
        self._baton_receiver_slp_addr = None
        self._parent_token_id = None
        self.discriminator = None

        self.wallet_id = wallet_id
        self.name = name
        self.ticker = ticker
        self.initial_amount = initial_amount
        self.decimals = decimals
        if document_url is not None:
            self.document_url = document_url
        if document_hash is not None:
            self.document_hash = document_hash
        if end_baton is not None:
            self.end_baton = end_baton
        if type is not None:
            self.type = type
        if token_receiver_slp_addr is not None:
            self.token_receiver_slp_addr = token_receiver_slp_addr
        if baton_receiver_slp_addr is not None:
            self.baton_receiver_slp_addr = baton_receiver_slp_addr
        if parent_token_id is not None:
            self.parent_token_id = parent_token_id

    @property
    def wallet_id(self):
        """Gets the wallet_id of this SlpGenesisRequest.  # noqa: E501

        ID that is returned in `wallet` field of /wallet call   # noqa: E501

        :return: The wallet_id of this SlpGenesisRequest.  # noqa: E501
        :rtype: str
        """
        return self._wallet_id

    @wallet_id.setter
    def wallet_id(self, wallet_id):
        """Sets the wallet_id of this SlpGenesisRequest.

        ID that is returned in `wallet` field of /wallet call   # noqa: E501

        :param wallet_id: The wallet_id of this SlpGenesisRequest.  # noqa: E501
        :type wallet_id: str
        """
        if self.local_vars_configuration.client_side_validation and wallet_id is None:  # noqa: E501
            raise ValueError("Invalid value for `wallet_id`, must not be `None`")  # noqa: E501

        self._wallet_id = wallet_id

    @property
    def name(self):
        """Gets the name of this SlpGenesisRequest.  # noqa: E501


        :return: The name of this SlpGenesisRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SlpGenesisRequest.


        :param name: The name of this SlpGenesisRequest.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def ticker(self):
        """Gets the ticker of this SlpGenesisRequest.  # noqa: E501

        Token ticker  # noqa: E501

        :return: The ticker of this SlpGenesisRequest.  # noqa: E501
        :rtype: str
        """
        return self._ticker

    @ticker.setter
    def ticker(self, ticker):
        """Sets the ticker of this SlpGenesisRequest.

        Token ticker  # noqa: E501

        :param ticker: The ticker of this SlpGenesisRequest.  # noqa: E501
        :type ticker: str
        """
        if self.local_vars_configuration.client_side_validation and ticker is None:  # noqa: E501
            raise ValueError("Invalid value for `ticker`, must not be `None`")  # noqa: E501

        self._ticker = ticker

    @property
    def initial_amount(self):
        """Gets the initial_amount of this SlpGenesisRequest.  # noqa: E501

        Value is represented as a string to avoid precision loss  # noqa: E501

        :return: The initial_amount of this SlpGenesisRequest.  # noqa: E501
        :rtype: str
        """
        return self._initial_amount

    @initial_amount.setter
    def initial_amount(self, initial_amount):
        """Sets the initial_amount of this SlpGenesisRequest.

        Value is represented as a string to avoid precision loss  # noqa: E501

        :param initial_amount: The initial_amount of this SlpGenesisRequest.  # noqa: E501
        :type initial_amount: str
        """
        if self.local_vars_configuration.client_side_validation and initial_amount is None:  # noqa: E501
            raise ValueError("Invalid value for `initial_amount`, must not be `None`")  # noqa: E501

        self._initial_amount = initial_amount

    @property
    def decimals(self):
        """Gets the decimals of this SlpGenesisRequest.  # noqa: E501

        Indicates that 1 token is divisible into 10^decimals base units  # noqa: E501

        :return: The decimals of this SlpGenesisRequest.  # noqa: E501
        :rtype: float
        """
        return self._decimals

    @decimals.setter
    def decimals(self, decimals):
        """Sets the decimals of this SlpGenesisRequest.

        Indicates that 1 token is divisible into 10^decimals base units  # noqa: E501

        :param decimals: The decimals of this SlpGenesisRequest.  # noqa: E501
        :type decimals: float
        """
        if self.local_vars_configuration.client_side_validation and decimals is None:  # noqa: E501
            raise ValueError("Invalid value for `decimals`, must not be `None`")  # noqa: E501

        self._decimals = decimals

    @property
    def document_url(self):
        """Gets the document_url of this SlpGenesisRequest.  # noqa: E501


        :return: The document_url of this SlpGenesisRequest.  # noqa: E501
        :rtype: str
        """
        return self._document_url

    @document_url.setter
    def document_url(self, document_url):
        """Sets the document_url of this SlpGenesisRequest.


        :param document_url: The document_url of this SlpGenesisRequest.  # noqa: E501
        :type document_url: str
        """

        self._document_url = document_url

    @property
    def document_hash(self):
        """Gets the document_hash of this SlpGenesisRequest.  # noqa: E501

        Document hash of the token. Empty or 64 character long hex string.  # noqa: E501

        :return: The document_hash of this SlpGenesisRequest.  # noqa: E501
        :rtype: str
        """
        return self._document_hash

    @document_hash.setter
    def document_hash(self, document_hash):
        """Sets the document_hash of this SlpGenesisRequest.

        Document hash of the token. Empty or 64 character long hex string.  # noqa: E501

        :param document_hash: The document_hash of this SlpGenesisRequest.  # noqa: E501
        :type document_hash: str
        """

        self._document_hash = document_hash

    @property
    def end_baton(self):
        """Gets the end_baton of this SlpGenesisRequest.  # noqa: E501

        Indicates if token should not be 'mintable', e.g. total circulation amount increased  # noqa: E501

        :return: The end_baton of this SlpGenesisRequest.  # noqa: E501
        :rtype: bool
        """
        return self._end_baton

    @end_baton.setter
    def end_baton(self, end_baton):
        """Sets the end_baton of this SlpGenesisRequest.

        Indicates if token should not be 'mintable', e.g. total circulation amount increased  # noqa: E501

        :param end_baton: The end_baton of this SlpGenesisRequest.  # noqa: E501
        :type end_baton: bool
        """

        self._end_baton = end_baton

    @property
    def type(self):
        """Gets the type of this SlpGenesisRequest.  # noqa: E501

        Token type. 0x01 Type1, 0x81 NFT Parent, 0x41 NFT Child  # noqa: E501

        :return: The type of this SlpGenesisRequest.  # noqa: E501
        :rtype: float
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SlpGenesisRequest.

        Token type. 0x01 Type1, 0x81 NFT Parent, 0x41 NFT Child  # noqa: E501

        :param type: The type of this SlpGenesisRequest.  # noqa: E501
        :type type: float
        """

        self._type = type

    @property
    def token_receiver_slp_addr(self):
        """Gets the token_receiver_slp_addr of this SlpGenesisRequest.  # noqa: E501


        :return: The token_receiver_slp_addr of this SlpGenesisRequest.  # noqa: E501
        :rtype: str
        """
        return self._token_receiver_slp_addr

    @token_receiver_slp_addr.setter
    def token_receiver_slp_addr(self, token_receiver_slp_addr):
        """Sets the token_receiver_slp_addr of this SlpGenesisRequest.


        :param token_receiver_slp_addr: The token_receiver_slp_addr of this SlpGenesisRequest.  # noqa: E501
        :type token_receiver_slp_addr: str
        """

        self._token_receiver_slp_addr = token_receiver_slp_addr

    @property
    def baton_receiver_slp_addr(self):
        """Gets the baton_receiver_slp_addr of this SlpGenesisRequest.  # noqa: E501


        :return: The baton_receiver_slp_addr of this SlpGenesisRequest.  # noqa: E501
        :rtype: str
        """
        return self._baton_receiver_slp_addr

    @baton_receiver_slp_addr.setter
    def baton_receiver_slp_addr(self, baton_receiver_slp_addr):
        """Sets the baton_receiver_slp_addr of this SlpGenesisRequest.


        :param baton_receiver_slp_addr: The baton_receiver_slp_addr of this SlpGenesisRequest.  # noqa: E501
        :type baton_receiver_slp_addr: str
        """

        self._baton_receiver_slp_addr = baton_receiver_slp_addr

    @property
    def parent_token_id(self):
        """Gets the parent_token_id of this SlpGenesisRequest.  # noqa: E501

        Identifier of the NFT parent token  # noqa: E501

        :return: The parent_token_id of this SlpGenesisRequest.  # noqa: E501
        :rtype: str
        """
        return self._parent_token_id

    @parent_token_id.setter
    def parent_token_id(self, parent_token_id):
        """Sets the parent_token_id of this SlpGenesisRequest.

        Identifier of the NFT parent token  # noqa: E501

        :param parent_token_id: The parent_token_id of this SlpGenesisRequest.  # noqa: E501
        :type parent_token_id: str
        """

        self._parent_token_id = parent_token_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SlpGenesisRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SlpGenesisRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class ContractFnRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'contract_id': 'str',
        'action': 'str',
        'function': 'str',
        'arguments': 'list[str]',
        'to': 'AnyOfSendRequestItemarrayCashscriptReceiptarray',
        'utxo_ids': 'list[str]',
        'op_return': 'list[str]',
        'fee_per_byte': 'float',
        'hardcoded_fee': 'float',
        'min_change': 'float',
        'without_change': 'bool',
        'age': 'float',
        'time': 'float'
    }

    attribute_map = {
        'contract_id': 'contractId',
        'action': 'action',
        'function': 'function',
        'arguments': 'arguments',
        'to': 'to',
        'utxo_ids': 'utxoIds',
        'op_return': 'opReturn',
        'fee_per_byte': 'feePerByte',
        'hardcoded_fee': 'hardcodedFee',
        'min_change': 'minChange',
        'without_change': 'withoutChange',
        'age': 'age',
        'time': 'time'
    }

    def __init__(self, contract_id=None, action='send', function=None, arguments=None, to=None, utxo_ids=None, op_return=None, fee_per_byte=None, hardcoded_fee=None, min_change=None, without_change=False, age=None, time=None, local_vars_configuration=None):  # noqa: E501
        """ContractFnRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._contract_id = None
        self._action = None
        self._function = None
        self._arguments = None
        self._to = None
        self._utxo_ids = None
        self._op_return = None
        self._fee_per_byte = None
        self._hardcoded_fee = None
        self._min_change = None
        self._without_change = None
        self._age = None
        self._time = None
        self.discriminator = None

        self.contract_id = contract_id
        if action is not None:
            self.action = action
        self.function = function
        if arguments is not None:
            self.arguments = arguments
        self.to = to
        if utxo_ids is not None:
            self.utxo_ids = utxo_ids
        if op_return is not None:
            self.op_return = op_return
        if fee_per_byte is not None:
            self.fee_per_byte = fee_per_byte
        if hardcoded_fee is not None:
            self.hardcoded_fee = hardcoded_fee
        if min_change is not None:
            self.min_change = min_change
        if without_change is not None:
            self.without_change = without_change
        if age is not None:
            self.age = age
        if time is not None:
            self.time = time

    @property
    def contract_id(self):
        """Gets the contract_id of this ContractFnRequest.  # noqa: E501

        serialized contract   # noqa: E501

        :return: The contract_id of this ContractFnRequest.  # noqa: E501
        :rtype: str
        """
        return self._contract_id

    @contract_id.setter
    def contract_id(self, contract_id):
        """Sets the contract_id of this ContractFnRequest.

        serialized contract   # noqa: E501

        :param contract_id: The contract_id of this ContractFnRequest.  # noqa: E501
        :type contract_id: str
        """
        if self.local_vars_configuration.client_side_validation and contract_id is None:  # noqa: E501
            raise ValueError("Invalid value for `contract_id`, must not be `None`")  # noqa: E501

        self._contract_id = contract_id

    @property
    def action(self):
        """Gets the action of this ContractFnRequest.  # noqa: E501

        In addition to `send`ing the built transaction, the built transaction hex may be returned (without broadcasting) with `build` action, or the [`meep 🔗`](https://github.com/gcash/meep) debugger command.  # noqa: E501

        :return: The action of this ContractFnRequest.  # noqa: E501
        :rtype: str
        """
        return self._action

    @action.setter
    def action(self, action):
        """Sets the action of this ContractFnRequest.

        In addition to `send`ing the built transaction, the built transaction hex may be returned (without broadcasting) with `build` action, or the [`meep 🔗`](https://github.com/gcash/meep) debugger command.  # noqa: E501

        :param action: The action of this ContractFnRequest.  # noqa: E501
        :type action: str
        """
        allowed_values = ["build", "send", "meep"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and action not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `action` ({0}), must be one of {1}"  # noqa: E501
                .format(action, allowed_values)
            )

        self._action = action

    @property
    def function(self):
        """Gets the function of this ContractFnRequest.  # noqa: E501

        Function to call on the cashscript contract.  # noqa: E501

        :return: The function of this ContractFnRequest.  # noqa: E501
        :rtype: str
        """
        return self._function

    @function.setter
    def function(self, function):
        """Sets the function of this ContractFnRequest.

        Function to call on the cashscript contract.  # noqa: E501

        :param function: The function of this ContractFnRequest.  # noqa: E501
        :type function: str
        """
        if self.local_vars_configuration.client_side_validation and function is None:  # noqa: E501
            raise ValueError("Invalid value for `function`, must not be `None`")  # noqa: E501

        self._function = function

    @property
    def arguments(self):
        """Gets the arguments of this ContractFnRequest.  # noqa: E501

        Arguments for the contract function call as strings.  Binary data should be passed as hexidecimal.  Signatures may be passed as wallet import format (WIF) or wallet strings (walletId). Cashscript expects `pubkey`s to be compressed 35 byte values.   # noqa: E501

        :return: The arguments of this ContractFnRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._arguments

    @arguments.setter
    def arguments(self, arguments):
        """Sets the arguments of this ContractFnRequest.

        Arguments for the contract function call as strings.  Binary data should be passed as hexidecimal.  Signatures may be passed as wallet import format (WIF) or wallet strings (walletId). Cashscript expects `pubkey`s to be compressed 35 byte values.   # noqa: E501

        :param arguments: The arguments of this ContractFnRequest.  # noqa: E501
        :type arguments: list[str]
        """

        self._arguments = arguments

    @property
    def to(self):
        """Gets the to of this ContractFnRequest.  # noqa: E501

        The output destination, as a SendRequest, cashscript style output(s), array of either.  # noqa: E501

        :return: The to of this ContractFnRequest.  # noqa: E501
        :rtype: AnyOfSendRequestItemarrayCashscriptReceiptarray
        """
        return self._to

    @to.setter
    def to(self, to):
        """Sets the to of this ContractFnRequest.

        The output destination, as a SendRequest, cashscript style output(s), array of either.  # noqa: E501

        :param to: The to of this ContractFnRequest.  # noqa: E501
        :type to: AnyOfSendRequestItemarrayCashscriptReceiptarray
        """
        if self.local_vars_configuration.client_side_validation and to is None:  # noqa: E501
            raise ValueError("Invalid value for `to`, must not be `None`")  # noqa: E501

        self._to = to

    @property
    def utxo_ids(self):
        """Gets the utxo_ids of this ContractFnRequest.  # noqa: E501

        Serialized utxoId(s) to spend from  # noqa: E501

        :return: The utxo_ids of this ContractFnRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._utxo_ids

    @utxo_ids.setter
    def utxo_ids(self, utxo_ids):
        """Sets the utxo_ids of this ContractFnRequest.

        Serialized utxoId(s) to spend from  # noqa: E501

        :param utxo_ids: The utxo_ids of this ContractFnRequest.  # noqa: E501
        :type utxo_ids: list[str]
        """

        self._utxo_ids = utxo_ids

    @property
    def op_return(self):
        """Gets the op_return of this ContractFnRequest.  # noqa: E501

        Add OP_RETURN outputs to the transaction. See [cashscript docs](https://cashscript.org/docs/sdk/transactions#withopreturn)   # noqa: E501

        :return: The op_return of this ContractFnRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._op_return

    @op_return.setter
    def op_return(self, op_return):
        """Sets the op_return of this ContractFnRequest.

        Add OP_RETURN outputs to the transaction. See [cashscript docs](https://cashscript.org/docs/sdk/transactions#withopreturn)   # noqa: E501

        :param op_return: The op_return of this ContractFnRequest.  # noqa: E501
        :type op_return: list[str]
        """

        self._op_return = op_return

    @property
    def fee_per_byte(self):
        """Gets the fee_per_byte of this ContractFnRequest.  # noqa: E501

        The withFeePerByte() function allows you to specify the fee per per bytes for the transaction. See [cashscript docs](https://cashscript.org/docs/sdk/transactions#withfeeperbyte)   # noqa: E501

        :return: The fee_per_byte of this ContractFnRequest.  # noqa: E501
        :rtype: float
        """
        return self._fee_per_byte

    @fee_per_byte.setter
    def fee_per_byte(self, fee_per_byte):
        """Sets the fee_per_byte of this ContractFnRequest.

        The withFeePerByte() function allows you to specify the fee per per bytes for the transaction. See [cashscript docs](https://cashscript.org/docs/sdk/transactions#withfeeperbyte)   # noqa: E501

        :param fee_per_byte: The fee_per_byte of this ContractFnRequest.  # noqa: E501
        :type fee_per_byte: float
        """

        self._fee_per_byte = fee_per_byte

    @property
    def hardcoded_fee(self):
        """Gets the hardcoded_fee of this ContractFnRequest.  # noqa: E501

        Specify a hardcoded fee to the transaction. By default the transaction fee is automatically calculated by the CashScript SDK. See [cashscript docs](https://cashscript.org/docs/sdk/transactions#withhardcodedfee)   # noqa: E501

        :return: The hardcoded_fee of this ContractFnRequest.  # noqa: E501
        :rtype: float
        """
        return self._hardcoded_fee

    @hardcoded_fee.setter
    def hardcoded_fee(self, hardcoded_fee):
        """Sets the hardcoded_fee of this ContractFnRequest.

        Specify a hardcoded fee to the transaction. By default the transaction fee is automatically calculated by the CashScript SDK. See [cashscript docs](https://cashscript.org/docs/sdk/transactions#withhardcodedfee)   # noqa: E501

        :param hardcoded_fee: The hardcoded_fee of this ContractFnRequest.  # noqa: E501
        :type hardcoded_fee: float
        """

        self._hardcoded_fee = hardcoded_fee

    @property
    def min_change(self):
        """Gets the min_change of this ContractFnRequest.  # noqa: E501

        Set a threshold for including a change output. Any remaining amount under this threshold will be added to the transaction fee instead. See [cashscript docs](https://cashscript.org/docs/sdk/transactions#withminchange)   # noqa: E501

        :return: The min_change of this ContractFnRequest.  # noqa: E501
        :rtype: float
        """
        return self._min_change

    @min_change.setter
    def min_change(self, min_change):
        """Sets the min_change of this ContractFnRequest.

        Set a threshold for including a change output. Any remaining amount under this threshold will be added to the transaction fee instead. See [cashscript docs](https://cashscript.org/docs/sdk/transactions#withminchange)   # noqa: E501

        :param min_change: The min_change of this ContractFnRequest.  # noqa: E501
        :type min_change: float
        """

        self._min_change = min_change

    @property
    def without_change(self):
        """Gets the without_change of this ContractFnRequest.  # noqa: E501

        Disable the change output. See [cashscript docs](https://cashscript.org/docs/sdk/transactions#withoutchange)   # noqa: E501

        :return: The without_change of this ContractFnRequest.  # noqa: E501
        :rtype: bool
        """
        return self._without_change

    @without_change.setter
    def without_change(self, without_change):
        """Sets the without_change of this ContractFnRequest.

        Disable the change output. See [cashscript docs](https://cashscript.org/docs/sdk/transactions#withoutchange)   # noqa: E501

        :param without_change: The without_change of this ContractFnRequest.  # noqa: E501
        :type without_change: bool
        """

        self._without_change = without_change

    @property
    def age(self):
        """Gets the age of this ContractFnRequest.  # noqa: E501

        Specify the minimum age of the transaction inputs. See [cashscript docs](https://cashscript.org/docs/sdk/transactions#withage)   # noqa: E501

        :return: The age of this ContractFnRequest.  # noqa: E501
        :rtype: float
        """
        return self._age

    @age.setter
    def age(self, age):
        """Sets the age of this ContractFnRequest.

        Specify the minimum age of the transaction inputs. See [cashscript docs](https://cashscript.org/docs/sdk/transactions#withage)   # noqa: E501

        :param age: The age of this ContractFnRequest.  # noqa: E501
        :type age: float
        """

        self._age = age

    @property
    def time(self):
        """Gets the time of this ContractFnRequest.  # noqa: E501

        Specify the minimum block number that the transaction can be included in. See [cashscript docs](https://cashscript.org/docs/sdk/transactions#withtime)   # noqa: E501

        :return: The time of this ContractFnRequest.  # noqa: E501
        :rtype: float
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this ContractFnRequest.

        Specify the minimum block number that the transaction can be included in. See [cashscript docs](https://cashscript.org/docs/sdk/transactions#withtime)   # noqa: E501

        :param time: The time of this ContractFnRequest.  # noqa: E501
        :type time: float
        """

        self._time = time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ContractFnRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ContractFnRequest):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mainnet
from mainnet.api.wallet_api import WalletApi  # noqa: E501
from mainnet.rest import ApiException


class TestWalletApi(unittest.TestCase):
    """WalletApi unit test stubs"""

    def setUp(self):
        self.api = mainnet.api.wallet_api.WalletApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_balance(self):
        """Test case for balance

        Get total balance for wallet  # noqa: E501
        """
        pass

    def test_create_wallet(self):
        """Test case for create_wallet

        create a new wallet  # noqa: E501
        """
        pass

    def test_deposit_address(self):
        """Test case for deposit_address

        Get a deposit address in cash address format  # noqa: E501
        """
        pass

    def test_deposit_qr(self):
        """Test case for deposit_qr

        Get receiving cash address as a qrcode  # noqa: E501
        """
        pass

    def test_info(self):
        """Test case for info

        Get information about a wallet  # noqa: E501
        """
        pass

    def test_max_amount_to_send(self):
        """Test case for max_amount_to_send

        Get maximum spendable amount  # noqa: E501
        """
        pass

    def test_named_exists(self):
        """Test case for named_exists

        Check if a named wallet already exists  # noqa: E501
        """
        pass

    def test_replace_named(self):
        """Test case for replace_named

        Replace (recover) named wallet with a new walletId. If wallet with a provided name does not exist yet, it will be creted with a `walletId` supplied If wallet exists it will be overwritten without exception   # noqa: E501
        """
        pass

    def test_send(self):
        """Test case for send

        Send some amount to a given address  # noqa: E501
        """
        pass

    def test_send_max(self):
        """Test case for send_max

        Send all available funds to a given address  # noqa: E501
        """
        pass

    def test_signed_message_sign(self):
        """Test case for signed_message_sign

        Returns the message signature  # noqa: E501
        """
        pass

    def test_signed_message_verify(self):
        """Test case for signed_message_verify

        Returns a boolean indicating whether message was valid for a given address  # noqa: E501
        """
        pass

    def test_utxos(self):
        """Test case for utxos

        Get detailed information about unspent outputs (utxos)  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mainnet
from mainnet.api.faucet_api import FaucetApi  # noqa: E501
from mainnet.rest import ApiException


class TestFaucetApi(unittest.TestCase):
    """FaucetApi unit test stubs"""

    def setUp(self):
        self.api = mainnet.api.faucet_api.FaucetApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_addresses(self):
        """Test case for get_addresses

        Get addresses to return back or donate the testnet bch and tokens   # noqa: E501
        """
        pass

    def test_get_testnet_bch(self):
        """Test case for get_testnet_bch

        Get testnet bch   # noqa: E501
        """
        pass

    def test_get_testnet_slp(self):
        """Test case for get_testnet_slp

        Get testnet slp tokens   # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.slp_genesis_request import SlpGenesisRequest  # noqa: E501
from mainnet.rest import ApiException

class TestSlpGenesisRequest(unittest.TestCase):
    """SlpGenesisRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test SlpGenesisRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.slp_genesis_request.SlpGenesisRequest()  # noqa: E501
        if include_optional :
            return SlpGenesisRequest(
                wallet_id = 'wif:testnet:cNfsPtqN2bMRS7vH5qd8tR8GMvgXyL5BjnGAKgZ8DYEiCrCCQcP6', 
                name = 'Mainnet coin', 
                ticker = 'MNC', 
                initial_amount = '10000', 
                decimals = 1.337, 
                document_url = 'https://mainnet.cash', 
                document_hash = 'db4451f11eda33950670aaf59e704da90117ff7057283b032cfaec7779313916', 
                end_baton = False, 
                type = 1, 
                token_receiver_slp_addr = 'slptest:qqm4gsaa2gvk7flvsvj7f0w4rlq32vqhkq32uar866', 
                baton_receiver_slp_addr = 'slptest:qqm4gsaa2gvk7flvsvj7f0w4rlq32vqhkq32uar866', 
                parent_token_id = '132731d90ac4c88a79d55eae2ad92709b415de886329e958cf35fdd81ba34c15'
            )
        else :
            return SlpGenesisRequest(
                wallet_id = 'wif:testnet:cNfsPtqN2bMRS7vH5qd8tR8GMvgXyL5BjnGAKgZ8DYEiCrCCQcP6',
                name = 'Mainnet coin',
                ticker = 'MNC',
                initial_amount = '10000',
                decimals = 1.337,
        )

    def testSlpGenesisRequest(self):
        """Test SlpGenesisRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.escrow_request import EscrowRequest  # noqa: E501
from mainnet.rest import ApiException

class TestEscrowRequest(unittest.TestCase):
    """EscrowRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EscrowRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.escrow_request.EscrowRequest()  # noqa: E501
        if include_optional :
            return EscrowRequest(
                buyer_addr = bchtest:qrnluuge56ahxsy6pplq43rva7k6s9dknu4p5278ah, 
                arbiter_addr = bchtest:qzspcywxmm4fqhf9kjrknrc3grsv2vukeqyjqla0nt, 
                seller_addr = bchtest:qz00pk9lfs0k9f5vf3j8h66qfmqagk8nc56elq4dv2, 
                amount = 10000
            )
        else :
            return EscrowRequest(
                buyer_addr = bchtest:qrnluuge56ahxsy6pplq43rva7k6s9dknu4p5278ah,
                arbiter_addr = bchtest:qzspcywxmm4fqhf9kjrknrc3grsv2vukeqyjqla0nt,
                seller_addr = bchtest:qz00pk9lfs0k9f5vf3j8h66qfmqagk8nc56elq4dv2,
                amount = 10000,
        )

    def testEscrowRequest(self):
        """Test EscrowRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import mainnet
from mainnet.api.contract_escrow_api import ContractEscrowApi  # noqa: E501
from mainnet.rest import ApiException


class TestContractEscrowApi(unittest.TestCase):
    """ContractEscrowApi unit test stubs"""

    def setUp(self):
        self.api = mainnet.api.contract_escrow_api.ContractEscrowApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_escrow(self):
        """Test case for create_escrow

        Create an escrow contract  # noqa: E501
        """
        pass

    def test_escrow_fn(self):
        """Test case for escrow_fn

        Finalize an escrow contract  # noqa: E501
        """
        pass

    def test_escrow_info(self):
        """Test case for escrow_info

        Get information about an escrow contract from the escrowContractId  # noqa: E501
        """
        pass

    def test_escrow_utxos(self):
        """Test case for escrow_utxos

        List specific utxos on any escrow contract  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.escrow_response import EscrowResponse  # noqa: E501
from mainnet.rest import ApiException

class TestEscrowResponse(unittest.TestCase):
    """EscrowResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test EscrowResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.escrow_response.EscrowResponse()  # noqa: E501
        if include_optional :
            return EscrowResponse(
                escrow_contract_id = 'escrowContract:testnet:WW1Ob2RHVnpkRHB4ZWpBd2NHczViR1p6TUdzNVpqVjJaak5xT0dnMk5uRm1iWEZoWjJzNGJtTTFObVZzY1RSa2RqST06WW1Ob2RHVnpkRHB4Y201c2RYVm5aVFUyWVdoNGMzazJjSEJzY1RRemNuWmhOMnMyY3psa2EyNTFOSEExTWpjNFlXZz06WW1Ob2RHVnpkRHB4ZW5Od1kzbDNlRzF0TkdaeGFHWTVhMnB5YTI1eVl6Tm5jbk4yTW5aMWEyVnhlV3B4YkdFd2JuUT06TVRBd01EQT0=:TVRVNExESTBNQ3d5TVRZc01Ua3hMRGMyTERNeExEazRMREUyTml3eE5EQXNOellzTVRBd0xERXlNeXd5TXpVc05qUXNOemdzTVRrekxESXhNaXc0T0N3eU5ETXNNVGszOk1qTXhMREkxTkN3eE1UTXNNalVzTVRZMkxERTROeXd4TVRVc05qUXNNVFUwTERnc01USTJMREV3TERFNU5pd3hNRGdzTWpNNUxERTNNeXd4Tmpnc01qRXNNVGd5TERFMU9RPT06TVRZd0xESTRMREUzTERFNU9Dd3lNaklzTWpNMExERTBOQ3c1TXl3ek55d3hPREFzTVRNMUxERXdOU3d4TkRNc01UY3NOalFzTWpJMExERTVOeXcxTVN3eE5UQXNNakF3Ok1UQXdNREE9Ok1UQTNOVEU0TkRjeU53PT0=:cHJhZ21hIGNhc2hzY3JpcHQgXjAuNi4xOwogICAgICAgICAgICBjb250cmFjdCBlc2Nyb3coYnl0ZXMyMCBzZWxsZXJQa2gsIGJ5dGVzMjAgYnV5ZXJQa2gsIGJ5dGVzMjAgYXJiaXRlclBraCwgaW50IGNvbnRyYWN0QW1vdW50LCBpbnQgY29udHJhY3ROb25jZSkgewoKICAgICAgICAgICAgICAgIGZ1bmN0aW9uIHNwZW5kKHB1YmtleSBzaWduaW5nUGssIHNpZyBzLCBpbnQgYW1vdW50LCBpbnQgbm9uY2UpIHsKICAgICAgICAgICAgICAgICAgICByZXF1aXJlKGhhc2gxNjAoc2lnbmluZ1BrKSA9PSBhcmJpdGVyUGtoIHx8IGhhc2gxNjAoc2lnbmluZ1BrKSA9PSBidXllclBraCk7CiAgICAgICAgICAgICAgICAgICAgcmVxdWlyZShjaGVja1NpZyhzLCBzaWduaW5nUGspKTsKICAgICAgICAgICAgICAgICAgICByZXF1aXJlKGFtb3VudCA+PSBjb250cmFjdEFtb3VudCk7CiAgICAgICAgICAgICAgICAgICAgcmVxdWlyZShub25jZSA9PSBjb250cmFjdE5vbmNlKTsKICAgICAgICAgICAgICAgICAgICBieXRlczM0IG91dHB1dCA9IG5ldyBPdXRwdXRQMlBLSChieXRlczgoYW1vdW50KSwgc2VsbGVyUGtoKTsKICAgICAgICAgICAgICAgICAgICByZXF1aXJlKGhhc2gyNTYob3V0cHV0KSA9PSB0eC5oYXNoT3V0cHV0cyk7CiAgICAgICAgICAgICAgICB9CgogICAgICAgICAgICAgICAgZnVuY3Rpb24gcmVmdW5kKHB1YmtleSBzaWduaW5nUGssIHNpZyBzLCBpbnQgYW1vdW50LCBpbnQgbm9uY2UpIHsKICAgICAgICAgICAgICAgICAgICByZXF1aXJlKGhhc2gxNjAoc2lnbmluZ1BrKSA9PSBhcmJpdGVyUGtofHxoYXNoMTYwKHNpZ25pbmdQaykgPT0gc2VsbGVyUGtoKTsKICAgICAgICAgICAgICAgICAgICByZXF1aXJlKGNoZWNrU2lnKHMsIHNpZ25pbmdQaykpOwogICAgICAgICAgICAgICAgICAgIHJlcXVpcmUoYW1vdW50ID49IGNvbnRyYWN0QW1vdW50KTsKICAgICAgICAgICAgICAgICAgICByZXF1aXJlKG5vbmNlID09IGNvbnRyYWN0Tm9uY2UpOwogICAgICAgICAgICAgICAgICAgIGJ5dGVzMzQgb3V0cHV0ID0gbmV3IE91dHB1dFAyUEtIKGJ5dGVzOChhbW91bnQpLCBidXllclBraCk7CiAgICAgICAgICAgICAgICAgICAgcmVxdWlyZShoYXNoMjU2KG91dHB1dCkgPT0gdHguaGFzaE91dHB1dHMpOwogICAgICAgICAgICAgICAgfQogICAgICAgICAgICB9CiAgICAgICAg:1075184727', 
                cashaddr = bchtest:qpttdv3qg2usm4nm7talhxhl05mlhms3ys43u76rn0
            )
        else :
            return EscrowResponse(
        )

    def testEscrowResponse(self):
        """Test EscrowResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from mainnet.api.contract_api import ContractApi
from mainnet.api.contract_escrow_api import ContractEscrowApi
from mainnet.api.faucet_api import FaucetApi
from mainnet.api.mine_api import MineApi
from mainnet.api.util_api import UtilApi
from mainnet.api.wallet_api import WalletApi
from mainnet.api.wallet_slp_api import WalletSlpApi
from mainnet.api.wallet_util_api import WalletUtilApi
from mainnet.api.webhook_api import WebhookApi

# import ApiClient
from mainnet.api_client import ApiClient
from mainnet.configuration import Configuration
from mainnet.exceptions import OpenApiException
from mainnet.exceptions import ApiTypeError
from mainnet.exceptions import ApiValueError
from mainnet.exceptions import ApiKeyError
from mainnet.exceptions import ApiAttributeError
from mainnet.exceptions import ApiException
# import models into sdk package
from mainnet.models.balance_request import BalanceRequest
from mainnet.models.balance_response import BalanceResponse
from mainnet.models.cashscript_receipt import CashscriptReceipt
from mainnet.models.contract import Contract
from mainnet.models.contract_fn_request import ContractFnRequest
from mainnet.models.contract_fn_response import ContractFnResponse
from mainnet.models.contract_info_request import ContractInfoRequest
from mainnet.models.contract_info_response import ContractInfoResponse
from mainnet.models.contract_request import ContractRequest
from mainnet.models.contract_response import ContractResponse
from mainnet.models.convert_request import ConvertRequest
from mainnet.models.create_signed_message_request import CreateSignedMessageRequest
from mainnet.models.deposit_address_response import DepositAddressResponse
from mainnet.models.electrum_raw_transaction import ElectrumRawTransaction
from mainnet.models.electrum_raw_transaction_script_pub_key import ElectrumRawTransactionScriptPubKey
from mainnet.models.electrum_raw_transaction_script_sig import ElectrumRawTransactionScriptSig
from mainnet.models.electrum_raw_transaction_vin import ElectrumRawTransactionVin
from mainnet.models.electrum_raw_transaction_vout import ElectrumRawTransactionVout
from mainnet.models.error import Error
from mainnet.models.escrow_contract import EscrowContract
from mainnet.models.escrow_fn_request import EscrowFnRequest
from mainnet.models.escrow_info_request import EscrowInfoRequest
from mainnet.models.escrow_info_response import EscrowInfoResponse
from mainnet.models.escrow_request import EscrowRequest
from mainnet.models.escrow_response import EscrowResponse
from mainnet.models.get_addresses_response import GetAddressesResponse
from mainnet.models.get_testnet_bch_request import GetTestnetBchRequest
from mainnet.models.get_testnet_bch_response import GetTestnetBchResponse
from mainnet.models.get_testnet_slp_request import GetTestnetSlpRequest
from mainnet.models.get_testnet_slp_response import GetTestnetSlpResponse
from mainnet.models.max_amount_to_send_request import MaxAmountToSendRequest
from mainnet.models.mine_request import MineRequest
from mainnet.models.network_enum import NetworkEnum
from mainnet.models.op_return_data import OpReturnData
from mainnet.models.scalable_vector_graphic import ScalableVectorGraphic
from mainnet.models.send_max_request import SendMaxRequest
from mainnet.models.send_max_response import SendMaxResponse
from mainnet.models.send_request import SendRequest
from mainnet.models.send_request_item import SendRequestItem
from mainnet.models.send_request_item_any_of import SendRequestItemAnyOf
from mainnet.models.send_request_options import SendRequestOptions
from mainnet.models.send_response import SendResponse
from mainnet.models.serialized_wallet import SerializedWallet
from mainnet.models.signed_message_response import SignedMessageResponse
from mainnet.models.signed_message_response_details import SignedMessageResponseDetails
from mainnet.models.signed_message_response_raw import SignedMessageResponseRaw
from mainnet.models.slp_balance_request import SlpBalanceRequest
from mainnet.models.slp_balance_response import SlpBalanceResponse
from mainnet.models.slp_deposit_address_response import SlpDepositAddressResponse
from mainnet.models.slp_genesis_request import SlpGenesisRequest
from mainnet.models.slp_genesis_response import SlpGenesisResponse
from mainnet.models.slp_mint_request import SlpMintRequest
from mainnet.models.slp_mint_response import SlpMintResponse
from mainnet.models.slp_outpoints_response import SlpOutpointsResponse
from mainnet.models.slp_send_max_request import SlpSendMaxRequest
from mainnet.models.slp_send_request import SlpSendRequest
from mainnet.models.slp_send_request_item import SlpSendRequestItem
from mainnet.models.slp_send_request_options import SlpSendRequestOptions
from mainnet.models.slp_send_response import SlpSendResponse
from mainnet.models.slp_token_info_request import SlpTokenInfoRequest
from mainnet.models.slp_token_info_response import SlpTokenInfoResponse
from mainnet.models.slp_utxo import SlpUtxo
from mainnet.models.slp_utxo_response import SlpUtxoResponse
from mainnet.models.unit_type import UnitType
from mainnet.models.util_decode_transaction_request import UtilDecodeTransactionRequest
from mainnet.models.utxo import Utxo
from mainnet.models.utxo_response import UtxoResponse
from mainnet.models.verify_signed_message_request import VerifySignedMessageRequest
from mainnet.models.verify_signed_message_response import VerifySignedMessageResponse
from mainnet.models.verify_signed_message_response_details import VerifySignedMessageResponseDetails
from mainnet.models.wallet_info import WalletInfo
from mainnet.models.wallet_mnemonic import WalletMnemonic
from mainnet.models.wallet_named_exists_request import WalletNamedExistsRequest
from mainnet.models.wallet_replace_named_request import WalletReplaceNamedRequest
from mainnet.models.wallet_request import WalletRequest
from mainnet.models.wallet_response import WalletResponse
from mainnet.models.wallet_type import WalletType
from mainnet.models.watch_address_request import WatchAddressRequest
from mainnet.models.watch_address_response import WatchAddressResponse
from mainnet.models.wif import Wif
from mainnet.models.zero_balance_response import ZeroBalanceResponse




# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.contract_info_response import ContractInfoResponse  # noqa: E501
from mainnet.rest import ApiException

class TestContractInfoResponse(unittest.TestCase):
    """ContractInfoResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ContractInfoResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.contract_info_response.ContractInfoResponse()  # noqa: E501
        if include_optional :
            return ContractInfoResponse(
                contract_id = '0', 
                script = 'contract TransferWithTimeout(pubkey sender, pubkey recipient, int timeout) {
    function transfer(sig recipientSig) {
        require(checkSig(recipientSig, recipient));
    }

    function timeout(sig senderSig) {
        require(checkSig(senderSig, sender));
        require(tx.time >= timeout);
    }
}            
', 
                parameters = ["03410ef048b3da351793f6ed14cc2fde460becc5b658d9138443b9a3000707a6a7","034978ac464f358b235f11212eb6e017af90215b90b1ff7471d9ae2abb5e09263b",215], 
                cashaddr = 'bchtest:qpalhxhl05mlhms3ys43u76rn0ttdv3qg2usm4nm7t'
            )
        else :
            return ContractInfoResponse(
        )

    def testContractInfoResponse(self):
        """Test ContractInfoResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class SlpUtxo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'index': 'float',
        'tx_id': 'str',
        'satoshis': 'float',
        'utxo_id': 'str',
        'value': 'str',
        'decimals': 'float',
        'ticker': 'str',
        'token_id': 'str',
        'type': 'float'
    }

    attribute_map = {
        'index': 'index',
        'tx_id': 'txId',
        'satoshis': 'satoshis',
        'utxo_id': 'utxoId',
        'value': 'value',
        'decimals': 'decimals',
        'ticker': 'ticker',
        'token_id': 'tokenId',
        'type': 'type'
    }

    def __init__(self, index=None, tx_id=None, satoshis=None, utxo_id=None, value=None, decimals=None, ticker=None, token_id=None, type=None, local_vars_configuration=None):  # noqa: E501
        """SlpUtxo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._index = None
        self._tx_id = None
        self._satoshis = None
        self._utxo_id = None
        self._value = None
        self._decimals = None
        self._ticker = None
        self._token_id = None
        self._type = None
        self.discriminator = None

        if index is not None:
            self.index = index
        if tx_id is not None:
            self.tx_id = tx_id
        if satoshis is not None:
            self.satoshis = satoshis
        if utxo_id is not None:
            self.utxo_id = utxo_id
        if value is not None:
            self.value = value
        if decimals is not None:
            self.decimals = decimals
        if ticker is not None:
            self.ticker = ticker
        if token_id is not None:
            self.token_id = token_id
        if type is not None:
            self.type = type

    @property
    def index(self):
        """Gets the index of this SlpUtxo.  # noqa: E501


        :return: The index of this SlpUtxo.  # noqa: E501
        :rtype: float
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this SlpUtxo.


        :param index: The index of this SlpUtxo.  # noqa: E501
        :type index: float
        """

        self._index = index

    @property
    def tx_id(self):
        """Gets the tx_id of this SlpUtxo.  # noqa: E501

        The hash of a transaction  # noqa: E501

        :return: The tx_id of this SlpUtxo.  # noqa: E501
        :rtype: str
        """
        return self._tx_id

    @tx_id.setter
    def tx_id(self, tx_id):
        """Sets the tx_id of this SlpUtxo.

        The hash of a transaction  # noqa: E501

        :param tx_id: The tx_id of this SlpUtxo.  # noqa: E501
        :type tx_id: str
        """

        self._tx_id = tx_id

    @property
    def satoshis(self):
        """Gets the satoshis of this SlpUtxo.  # noqa: E501

        Locked satoshi  # noqa: E501

        :return: The satoshis of this SlpUtxo.  # noqa: E501
        :rtype: float
        """
        return self._satoshis

    @satoshis.setter
    def satoshis(self, satoshis):
        """Sets the satoshis of this SlpUtxo.

        Locked satoshi  # noqa: E501

        :param satoshis: The satoshis of this SlpUtxo.  # noqa: E501
        :type satoshis: float
        """

        self._satoshis = satoshis

    @property
    def utxo_id(self):
        """Gets the utxo_id of this SlpUtxo.  # noqa: E501

        serialized outpoint  # noqa: E501

        :return: The utxo_id of this SlpUtxo.  # noqa: E501
        :rtype: str
        """
        return self._utxo_id

    @utxo_id.setter
    def utxo_id(self, utxo_id):
        """Sets the utxo_id of this SlpUtxo.

        serialized outpoint  # noqa: E501

        :param utxo_id: The utxo_id of this SlpUtxo.  # noqa: E501
        :type utxo_id: str
        """

        self._utxo_id = utxo_id

    @property
    def value(self):
        """Gets the value of this SlpUtxo.  # noqa: E501

        Token amount represented as a string to avoid precision loss  # noqa: E501

        :return: The value of this SlpUtxo.  # noqa: E501
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this SlpUtxo.

        Token amount represented as a string to avoid precision loss  # noqa: E501

        :param value: The value of this SlpUtxo.  # noqa: E501
        :type value: str
        """

        self._value = value

    @property
    def decimals(self):
        """Gets the decimals of this SlpUtxo.  # noqa: E501

        Indicates that 1 token is divisible into 10^decimals base units  # noqa: E501

        :return: The decimals of this SlpUtxo.  # noqa: E501
        :rtype: float
        """
        return self._decimals

    @decimals.setter
    def decimals(self, decimals):
        """Sets the decimals of this SlpUtxo.

        Indicates that 1 token is divisible into 10^decimals base units  # noqa: E501

        :param decimals: The decimals of this SlpUtxo.  # noqa: E501
        :type decimals: float
        """

        self._decimals = decimals

    @property
    def ticker(self):
        """Gets the ticker of this SlpUtxo.  # noqa: E501

        Token ticker  # noqa: E501

        :return: The ticker of this SlpUtxo.  # noqa: E501
        :rtype: str
        """
        return self._ticker

    @ticker.setter
    def ticker(self, ticker):
        """Sets the ticker of this SlpUtxo.

        Token ticker  # noqa: E501

        :param ticker: The ticker of this SlpUtxo.  # noqa: E501
        :type ticker: str
        """

        self._ticker = ticker

    @property
    def token_id(self):
        """Gets the token_id of this SlpUtxo.  # noqa: E501

        Token unique hexadecimal identifier, also the id of the token creation transaction  # noqa: E501

        :return: The token_id of this SlpUtxo.  # noqa: E501
        :rtype: str
        """
        return self._token_id

    @token_id.setter
    def token_id(self, token_id):
        """Sets the token_id of this SlpUtxo.

        Token unique hexadecimal identifier, also the id of the token creation transaction  # noqa: E501

        :param token_id: The token_id of this SlpUtxo.  # noqa: E501
        :type token_id: str
        """

        self._token_id = token_id

    @property
    def type(self):
        """Gets the type of this SlpUtxo.  # noqa: E501

        Token type. 0x01 Type1, 0x81 NFT Parent, 0x41 NFT Child  # noqa: E501

        :return: The type of this SlpUtxo.  # noqa: E501
        :rtype: float
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this SlpUtxo.

        Token type. 0x01 Type1, 0x81 NFT Parent, 0x41 NFT Child  # noqa: E501

        :param type: The type of this SlpUtxo.  # noqa: E501
        :type type: float
        """

        self._type = type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SlpUtxo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SlpUtxo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class EscrowInfoResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'escrow_contract_id': 'str',
        'script': 'str',
        'parameters': 'list[str]',
        'cashaddr': 'str',
        'buyer_addr': 'object',
        'arbiter_addr': 'object',
        'seller_addr': 'object',
        'amount': 'float',
        'nonce': 'float'
    }

    attribute_map = {
        'escrow_contract_id': 'escrowContractId',
        'script': 'script',
        'parameters': 'parameters',
        'cashaddr': 'cashaddr',
        'buyer_addr': 'buyerAddr',
        'arbiter_addr': 'arbiterAddr',
        'seller_addr': 'sellerAddr',
        'amount': 'amount',
        'nonce': 'nonce'
    }

    def __init__(self, escrow_contract_id=None, script=None, parameters=None, cashaddr=None, buyer_addr=None, arbiter_addr=None, seller_addr=None, amount=None, nonce=None, local_vars_configuration=None):  # noqa: E501
        """EscrowInfoResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._escrow_contract_id = None
        self._script = None
        self._parameters = None
        self._cashaddr = None
        self._buyer_addr = None
        self._arbiter_addr = None
        self._seller_addr = None
        self._amount = None
        self._nonce = None
        self.discriminator = None

        if escrow_contract_id is not None:
            self.escrow_contract_id = escrow_contract_id
        if script is not None:
            self.script = script
        if parameters is not None:
            self.parameters = parameters
        if cashaddr is not None:
            self.cashaddr = cashaddr
        self.buyer_addr = buyer_addr
        self.arbiter_addr = arbiter_addr
        self.seller_addr = seller_addr
        if amount is not None:
            self.amount = amount
        if nonce is not None:
            self.nonce = nonce

    @property
    def escrow_contract_id(self):
        """Gets the escrow_contract_id of this EscrowInfoResponse.  # noqa: E501

        serialized escrow contract   # noqa: E501

        :return: The escrow_contract_id of this EscrowInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._escrow_contract_id

    @escrow_contract_id.setter
    def escrow_contract_id(self, escrow_contract_id):
        """Sets the escrow_contract_id of this EscrowInfoResponse.

        serialized escrow contract   # noqa: E501

        :param escrow_contract_id: The escrow_contract_id of this EscrowInfoResponse.  # noqa: E501
        :type escrow_contract_id: str
        """

        self._escrow_contract_id = escrow_contract_id

    @property
    def script(self):
        """Gets the script of this EscrowInfoResponse.  # noqa: E501

        The escrow contract in cashscript syntax   # noqa: E501

        :return: The script of this EscrowInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._script

    @script.setter
    def script(self, script):
        """Sets the script of this EscrowInfoResponse.

        The escrow contract in cashscript syntax   # noqa: E501

        :param script: The script of this EscrowInfoResponse.  # noqa: E501
        :type script: str
        """

        self._script = script

    @property
    def parameters(self):
        """Gets the parameters of this EscrowInfoResponse.  # noqa: E501

        Parameters passed when the contract was created  # noqa: E501

        :return: The parameters of this EscrowInfoResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """Sets the parameters of this EscrowInfoResponse.

        Parameters passed when the contract was created  # noqa: E501

        :param parameters: The parameters of this EscrowInfoResponse.  # noqa: E501
        :type parameters: list[str]
        """

        self._parameters = parameters

    @property
    def cashaddr(self):
        """Gets the cashaddr of this EscrowInfoResponse.  # noqa: E501


        :return: The cashaddr of this EscrowInfoResponse.  # noqa: E501
        :rtype: str
        """
        return self._cashaddr

    @cashaddr.setter
    def cashaddr(self, cashaddr):
        """Sets the cashaddr of this EscrowInfoResponse.


        :param cashaddr: The cashaddr of this EscrowInfoResponse.  # noqa: E501
        :type cashaddr: str
        """

        self._cashaddr = cashaddr

    @property
    def buyer_addr(self):
        """Gets the buyer_addr of this EscrowInfoResponse.  # noqa: E501

        The cashaddress of the buyer  # noqa: E501

        :return: The buyer_addr of this EscrowInfoResponse.  # noqa: E501
        :rtype: object
        """
        return self._buyer_addr

    @buyer_addr.setter
    def buyer_addr(self, buyer_addr):
        """Sets the buyer_addr of this EscrowInfoResponse.

        The cashaddress of the buyer  # noqa: E501

        :param buyer_addr: The buyer_addr of this EscrowInfoResponse.  # noqa: E501
        :type buyer_addr: object
        """

        self._buyer_addr = buyer_addr

    @property
    def arbiter_addr(self):
        """Gets the arbiter_addr of this EscrowInfoResponse.  # noqa: E501

        The cashaddress of the arbiter  # noqa: E501

        :return: The arbiter_addr of this EscrowInfoResponse.  # noqa: E501
        :rtype: object
        """
        return self._arbiter_addr

    @arbiter_addr.setter
    def arbiter_addr(self, arbiter_addr):
        """Sets the arbiter_addr of this EscrowInfoResponse.

        The cashaddress of the arbiter  # noqa: E501

        :param arbiter_addr: The arbiter_addr of this EscrowInfoResponse.  # noqa: E501
        :type arbiter_addr: object
        """

        self._arbiter_addr = arbiter_addr

    @property
    def seller_addr(self):
        """Gets the seller_addr of this EscrowInfoResponse.  # noqa: E501

        The cashaddress of the seller  # noqa: E501

        :return: The seller_addr of this EscrowInfoResponse.  # noqa: E501
        :rtype: object
        """
        return self._seller_addr

    @seller_addr.setter
    def seller_addr(self, seller_addr):
        """Sets the seller_addr of this EscrowInfoResponse.

        The cashaddress of the seller  # noqa: E501

        :param seller_addr: The seller_addr of this EscrowInfoResponse.  # noqa: E501
        :type seller_addr: object
        """

        self._seller_addr = seller_addr

    @property
    def amount(self):
        """Gets the amount of this EscrowInfoResponse.  # noqa: E501

        Numeric amount to be transferred by the contract in satoshi, amount must be less than 21 BCH.  # noqa: E501

        :return: The amount of this EscrowInfoResponse.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this EscrowInfoResponse.

        Numeric amount to be transferred by the contract in satoshi, amount must be less than 21 BCH.  # noqa: E501

        :param amount: The amount of this EscrowInfoResponse.  # noqa: E501
        :type amount: float
        """

        self._amount = amount

    @property
    def nonce(self):
        """Gets the nonce of this EscrowInfoResponse.  # noqa: E501

        A unique number used once for each instance of a contract.  # noqa: E501

        :return: The nonce of this EscrowInfoResponse.  # noqa: E501
        :rtype: float
        """
        return self._nonce

    @nonce.setter
    def nonce(self, nonce):
        """Sets the nonce of this EscrowInfoResponse.

        A unique number used once for each instance of a contract.  # noqa: E501

        :param nonce: The nonce of this EscrowInfoResponse.  # noqa: E501
        :type nonce: float
        """

        self._nonce = nonce

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, EscrowInfoResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, EscrowInfoResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in *active* development, breaking changes may be made prior to official release of version 1.0.0.   # noqa: E501

    The version of the OpenAPI document: 0.3.39
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class SignedMessageResponseRaw(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'ecdsa': 'str',
        'schnorr': 'str',
        'der': 'str'
    }

    attribute_map = {
        'ecdsa': 'ecdsa',
        'schnorr': 'schnorr',
        'der': 'der'
    }

    def __init__(self, ecdsa=None, schnorr=None, der=None, local_vars_configuration=None):  # noqa: E501
        """SignedMessageResponseRaw - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._ecdsa = None
        self._schnorr = None
        self._der = None
        self.discriminator = None

        if ecdsa is not None:
            self.ecdsa = ecdsa
        if schnorr is not None:
            self.schnorr = schnorr
        if der is not None:
            self.der = der

    @property
    def ecdsa(self):
        """Gets the ecdsa of this SignedMessageResponseRaw.  # noqa: E501

        Elliptic Curve Digital messageHash encoded as a base64 string  # noqa: E501

        :return: The ecdsa of this SignedMessageResponseRaw.  # noqa: E501
        :rtype: str
        """
        return self._ecdsa

    @ecdsa.setter
    def ecdsa(self, ecdsa):
        """Sets the ecdsa of this SignedMessageResponseRaw.

        Elliptic Curve Digital messageHash encoded as a base64 string  # noqa: E501

        :param ecdsa: The ecdsa of this SignedMessageResponseRaw.  # noqa: E501
        :type ecdsa: str
        """

        self._ecdsa = ecdsa

    @property
    def schnorr(self):
        """Gets the schnorr of this SignedMessageResponseRaw.  # noqa: E501

        Schnorr signature of the messageHash encoded as a base64 string, Note from libauth: Nonces are generated using RFC6979, where the Section 3.6, 16-byte ASCII \"additional data\" is set to Schnorr+SHA256, see https://libauth.org/interfaces/secp256k1.html#signmessagehashschnorr   # noqa: E501

        :return: The schnorr of this SignedMessageResponseRaw.  # noqa: E501
        :rtype: str
        """
        return self._schnorr

    @schnorr.setter
    def schnorr(self, schnorr):
        """Sets the schnorr of this SignedMessageResponseRaw.

        Schnorr signature of the messageHash encoded as a base64 string, Note from libauth: Nonces are generated using RFC6979, where the Section 3.6, 16-byte ASCII \"additional data\" is set to Schnorr+SHA256, see https://libauth.org/interfaces/secp256k1.html#signmessagehashschnorr   # noqa: E501

        :param schnorr: The schnorr of this SignedMessageResponseRaw.  # noqa: E501
        :type schnorr: str
        """

        self._schnorr = schnorr

    @property
    def der(self):
        """Gets the der of this SignedMessageResponseRaw.  # noqa: E501

        Signature of messageHash using DER (Distinguished Encoding Rules)   # noqa: E501

        :return: The der of this SignedMessageResponseRaw.  # noqa: E501
        :rtype: str
        """
        return self._der

    @der.setter
    def der(self, der):
        """Sets the der of this SignedMessageResponseRaw.

        Signature of messageHash using DER (Distinguished Encoding Rules)   # noqa: E501

        :param der: The der of this SignedMessageResponseRaw.  # noqa: E501
        :type der: str
        """

        self._der = der

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SignedMessageResponseRaw):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SignedMessageResponseRaw):
            return True

        return self.to_dict() != other.to_dict()
